#! /usr/bin/env python

import click
from wordnik import *

API_URL = 'http://api.wordnik.com/v4'


class Look():
    def __init__(self, word, api_key):
        self.word = word
        self.api_key = api_key
        self.api_url = API_URL
        self.client = swagger.ApiClient(self.api_key, self.api_url)
        self.word_api = WordApi.WordApi(self.client)
        self.words_api = WordsApi.WordsApi(self.client)

    def is_valid_word(self):
        defn = self.word_api.getDefinitions(self.word)
        if defn:
            return True
        return False

    def print_defn(self):
        defn = self.word_api.getDefinitions(self.word)
        defn_text = defn[0].text

        click.secho(self.word, fg='green')
        click.secho(defn_text, fg='white')
        print ''

    def print_examples(self):
        example_search_result = self.word_api.getExamples(word=self.word,
                                                          limit=5)

        click.secho('Some examples', fg='blue')

        for example in example_search_result.examples:
            click.secho(example.text, fg='white')

        print ''

    def print_pronunciations(self):
        pronunciations = self.word_api.getTextPronunciations(word=self.word,
                                            limit=5)

        if not pronunciations:
            click.secho('Pronunciation not available', fg='red')
            return
        click.secho('Pronunciation', fg='yellow')

        for pronunciation in pronunciations:
            click.secho(pronunciation.raw, fg='white')

        print ''


def word_of_day(api_key):
    client = swagger.ApiClient(api_key, API_URL)
    words_api = WordsApi.WordsApi(client)

    word_of_day = words_api.getWordOfTheDay()

    click.secho('Word of the day', fg='green')

    print ''
    return word_of_day.word


#! /usr/bin/env python

import os
import argparse

from look import Look
from look import word_of_day

WORDNIK_API_KEY = os.environ.get("WORDNIK_API_KEY")


def is_api_set():
    if WORDNIK_API_KEY is None:
        return False
    return True

def parse_args():
    parser = argparse.ArgumentParser(description='Get the meaning of a word '\
                                     'or get word of day by ignoring options')
    parser.add_argument("-w", "--word", help="Meaning of the word")

    # Optional arguments
    parser.add_argument("-e", "--examples", help="Display with examples",
                        action="store_true")

    parser.add_argument("-p", "--pronounce", help="Get pronunciation",
                        action="store_true")

    args = parser.parse_args()

    # Check if env variable is set
    if not is_api_set():
        print 'Please set WORDNIK_API_KEY env variable \n'
        return

    if not args.word:
        word = word_of_day(WORDNIK_API_KEY)
    else:
        word = args.word

    # Initialize look object
    look = Look(word, WORDNIK_API_KEY)

    # Check if the word is valid
    if not look.is_valid_word():
        print 'Unable to find %s in dictionary' %word
        return

    # Print definition of word by default
    look.print_defn()

    if args.pronounce:
        look.print_pronunciations()

    if args.examples:
        look.print_examples()


def main():
    parse_args()



from setuptools import setup


setup(
    name = "look-up",
    version = "0.1.1",
    author = "Dinesh S",
    author_email = "dineshpy07@gmail.com",
    description = ("Get the meaning of a word on your terminal"),
    license = "MIT",
    keywords = "english dictionary words",
    url = "https://github.com/Dineshs91/lookup",
    packages = ['lookup'],
    long_description = "Get the meaning of a word, its pronunciation and "\
                       "examples. Also get word of the day",
    install_requires = [
        "click>=5.0",
        "wordnik==2.1.3"
    ],
    entry_points = {
        'console_scripts': [
            'look-up=lookup:main'
        ],
    }
)